CustomerProfile class

Constructors

CustomerProfile.rehydrate({required CustomerId customerId, required DateTime joinedAt, required DateTime lastInteractionAt, required CommunicationPreference preference, String? notes})
CustomerProfile.newProfile({required CustomerId customerId, required DateTime joinedAt, CommunicationPreference preference = CommunicationPreference.phone})

Properties

communicationPreference CommunicationPreference
no setter
customerId CustomerId
final
hashCode int
The hash code for this object.
no setterinherited
joinedAt DateTime
final
lastInteractionAt DateTime
no setter
notes String?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

appendSystemNote(String note) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
updateCommunicationPreference(CommunicationPreference newPreference, {required Clock clock}) → void
updateLastInteraction(DateTime timestamp) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited