RelationshipEvolutionService class
Constructors
- RelationshipEvolutionService(RelationshipProgressionPolicy _policy, AnalyticsSinkPort _analytics, Clock _clock)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
evaluateUpgrade(
BrandRelationship relationship, int orderCount) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited